@@ -1,5 +1,5 @@
 #  File src/library/grDevices/R/unix/x11.R
-#  Part of the R package, http://www.R-project.org
+#  Part of the R package, https://www.R-project.org
 #
 #  Copyright (C) 1995-2014 The R Core Team
 #
@@ -14,7 +14,7 @@
 #  GNU General Public License for more details.
 #
 #  A copy of the GNU General Public License is available at
-#  http://www.r-project.org/Licenses/
+#  https://www.R-project.org/Licenses/
 
 ## An environment not exported from namespace:grDevices used to
 ## pass .X11.Fonts to the X11 device.
@@ -29,6 +29,7 @@ assign(".X11.Options",
             fonts = c("-adobe-helvetica-%s-%s-*-*-%d-*-*-*-*-*-*-*",
             "-adobe-symbol-medium-r-*-*-%d-*-*-*-*-*-*-*"),
             family = "sans",
+            symbolfamily = "default",
             xpos = NA_integer_, ypos = NA_integer_,
 	    title = "", type = "cairo", antialias = "default"),
        envir = .X11env)
@@ -53,22 +54,10 @@ X11.options <- function(..., reset = FALSE)
     if(reset || l... > 0) invisible(old) else old
 }
 
-check_for_XQuartz <- function()
-{
-    DSO <- file.path(R.home("modules"), "R_X11.so")
-    out <- system2("otool", c("-L", shQuote(DSO)), stdout = TRUE)
-    ind <- grep("libX11[.][0-9]+[.]dylib", out)
-    if(length(ind)) {
-        this <- sub(" .*", "", sub("^\t", "", out[ind]))
-        if(!file.exists(this))
-            stop("X11 library is missing: install XQuartz from xquartz.macosforge.org", domain = NA)
-    }
-}
-
-
+x11 <-
 X11 <- function(display = "", width, height, pointsize, gamma,
                 bg, canvas, fonts, family,
-                xpos, ypos, title, type, antialias)
+                xpos, ypos, title, type, antialias, symbolfamily)
 {
     if(display != "XImage") { # used by tkrplot
         check <- Sys.getenv("_R_CHECK_SCREEN_DEVICE_", "")
@@ -103,6 +92,7 @@ X11 <- function(display = "", width, height, pointsize, gamma,
     if(!missing(fonts)) new$fonts <- fonts
     if(!missing(antialias) && type != "Xlib")
         new$antialias <- match.arg(antialias, aa.cairo)
+    if(!missing(symbolfamily)) new$symbolfamily <- symbolfamily
     d <- check.options(new, name.opt = ".X11.Options", envir = .X11env)
     if(d$type == "Xlib" && !missing(family)) {
         fns <- X11Fonts()
@@ -117,16 +107,15 @@ X11 <- function(display = "", width, height, pointsize, gamma,
     ## Aargh -- trkplot has a trapdoor and does not set type.
     if (display == "XImage") type <- 0L
     antialias <- match(d$antialias, aa.cairo)
-    if (grepl("darwin", R.version$os)) check_for_XQuartz()
+    if (grepl("darwin", R.version$os))
+        utils:::check_for_XQuartz(file.path(R.home("modules"), "R_X11.so"))
     .External2(C_X11, d$display, d$width, d$height, d$pointsize, d$gamma,
                d$colortype, d$maxcubesize, d$bg, d$canvas, d$fonts,
                NA_integer_, d$xpos, d$ypos, d$title,
-               type, antialias, d$family)
+               type, antialias, d$family, optionSymbolFont(d$symbolfamily))
     invisible()
 }
 
-x11 <- X11
-
 
 ####################
 # X11 font database
@@ -167,12 +156,12 @@ setX11Fonts <- function(fonts, fontNames)
     assign(".X11.Fonts", fontDB, envir=.X11env)
 }
 
-printFont <- function(font) paste(font, "\n", sep="")
+printFont <- function(font) paste0(font, "\n")
 
 
 printFonts <- function(fonts)
-    cat(paste(names(fonts), ": ", unlist(lapply(fonts, printFont)),
-              sep="", collapse=""))
+    cat(paste0(names(fonts), ": ", unlist(lapply(fonts, printFont)),
+               collapse=""))
 
 # If no arguments spec'ed, return entire font database
 # If no named arguments spec'ed, all args should be font names
@@ -218,7 +207,7 @@ X11Fonts(# Default Serif font is Times
          Mincho = X11Font("-*-mincho-%s-%s-*-*-%d-*-*-*-*-*-*-*")
          )
 
-savePlot <- function(filename = paste("Rplot", type, sep="."),
+savePlot <- function(filename = paste0("Rplot.", type),
                      type = c("png", "jpeg", "tiff", "bmp"),
                      device = dev.cur())
 {
@@ -231,3 +220,16 @@ savePlot <- function(filename = paste("Rplot", type, sep="."),
         stop("can only copy from 'X11(type=\"*cairo\")' devices")
     invisible(.External2(C_savePlot, filename, type, device))
 }
+
+
+optionSymbolFont <- function(family) {
+    if (family == "default") {
+        if (symbolType1support()) {
+            cairoSymbolFont("symbol")
+        } else {
+            cairoSymbolFont("sans", usePUA = FALSE)
+        }
+    } else {
+        checkSymbolFont(family)
+    }
+}
